@@ -5,7 +5,7 @@
  * object level logging, and fully-qualified object names for all DML and DDL
  * statements where possible (See README.md for details).
  *
- * Copyright (c) 2014-2020, PostgreSQL Global Development Group
+ * Copyright (c) 2014-2015, PostgreSQL Global Development Group
  *------------------------------------------------------------------------------
  */
 #include "postgres.h"
@@ -25,7 +25,6 @@
 #include "miscadmin.h"
 #include "libpq/auth.h"
 #include "nodes/nodes.h"
-#include "nodes/params.h"
 #include "tcop/utility.h"
 #include "tcop/deparse_utility.h"
 #include "utils/acl.h"
@@ -495,7 +494,7 @@ log_audit_event(AuditEventStackItem *stackItem)
 
             switch (stackItem->auditEvent.commandTag)
             {
-                /* Currently, only EXECUTE is different */
+                    /* Currently, only EXECUTE is different */
                 case T_ExecuteStmt:
                     className = CLASS_MISC;
                     class = LOG_MISC;
@@ -597,7 +596,7 @@ log_audit_event(AuditEventStackItem *stackItem)
         case LOGSTMT_ALL:
             switch (stackItem->auditEvent.commandTag)
             {
-                /* READ statements */
+                    /* READ statements */
                 case T_CopyStmt:
                 case T_SelectStmt:
                 case T_PrepareStmt:
@@ -606,7 +605,7 @@ log_audit_event(AuditEventStackItem *stackItem)
                     class = LOG_READ;
                     break;
 
-                /* FUNCTION statements */
+                    /* FUNCTION statements */
                 case T_DoStmt:
                     className = CLASS_FUNCTION;
                     class = LOG_FUNCTION;
@@ -736,7 +735,7 @@ log_audit_event(AuditEventStackItem *stackItem)
      * translatability, but we currently haven't got translation support in
      * pgaudit anyway.
      */
-    ereport(auditLogClient ? auditLogLevel : COMMERROR,
+    ereport(auditLogClient ? auditLogLevel : LOG_SERVER_ONLY,
             (errmsg("AUDIT: %s," INT64_FORMAT "," INT64_FORMAT ",%s,%s",
                     stackItem->auditEvent.granted ?
                     AUDIT_TYPE_OBJECT : AUDIT_TYPE_SESSION,
@@ -970,7 +969,7 @@ log_select_dml(Oid auditOid, List *rangeTabls)
     foreach(lr, rangeTabls)
     {
         Oid relOid;
-        Oid relNamespaceOid;
+        Relation rel;
         RangeTblEntry *rte = lfirst(lr);
 
         /* We only care about tables, and can ignore subqueries etc. */
@@ -993,10 +992,13 @@ log_select_dml(Oid auditOid, List *rangeTabls)
          * false) then filter out any system relations here.
          */
         relOid = rte->relid;
-        relNamespaceOid = get_rel_namespace(relOid);
+        rel = relation_open(relOid, NoLock);
 
-        if (!auditLogCatalog && IsSystemNamespace(relNamespaceOid))
+        if (!auditLogCatalog && IsSystemNamespace(RelationGetNamespace(rel)))
+        {
+            relation_close(rel, NoLock);
             continue;
+        }
 
         /*
          * Default is that this was not through a grant, to support session
@@ -1093,8 +1095,10 @@ log_select_dml(Oid auditOid, List *rangeTabls)
 
         /* Get a copy of the relation name and assign it to object name */
         auditEventStack->auditEvent.objectName =
-            quote_qualified_identifier(
-                get_namespace_name(relNamespaceOid), get_rel_name(relOid));
+            quote_qualified_identifier(get_namespace_name(
+                                           RelationGetNamespace(rel)),
+                                       RelationGetRelationName(rel));
+        relation_close(rel, NoLock);
 
         /* Perform object auditing only if the audit role is valid */
         if (auditOid != InvalidOid)
@@ -1289,7 +1293,7 @@ pgaudit_ExecutorStart_hook(QueryDesc *queryDesc, int eflags)
 
         /* Initialize the audit event */
         stackItem->auditEvent.commandText = queryDesc->sourceText;
-        stackItem->auditEvent.paramList = copyParamList(queryDesc->params);
+        stackItem->auditEvent.paramList = queryDesc->params;
     }
 
     /* Call the previous hook or standard function */
@@ -1339,11 +1343,11 @@ pgaudit_ExecutorCheckPerms_hook(List *rangeTabls, bool abort)
  */
 static void
 pgaudit_ProcessUtility_hook(Node *parsetree,
-                            const char *queryString,
-                            ProcessUtilityContext context,
-                            ParamListInfo params,
-                            DestReceiver *dest,
-                            char *completionTag)
+                             const char *queryString,
+                             ProcessUtilityContext context,
+                             ParamListInfo params,
+                             DestReceiver *dest,
+                             char *completionTag)
 {
     AuditEventStackItem *stackItem = NULL;
     int64 stackId = 0;
@@ -1357,30 +1361,11 @@ pgaudit_ProcessUtility_hook(Node *parsetree,
         /* Process top level utility statement */
         if (context == PROCESS_UTILITY_TOPLEVEL)
         {
-            /*
-             * If the stack is not empty then the only allowed entries are open
-             * select, show, and explain cursors
-             */
             if (auditEventStack != NULL)
-            {
-                AuditEventStackItem *nextItem = auditEventStack;
-
-                do
-                {
-                    if (nextItem->auditEvent.commandTag != T_SelectStmt &&
-                        nextItem->auditEvent.commandTag != T_VariableShowStmt &&
-                        nextItem->auditEvent.commandTag != T_ExplainStmt)
-                    {
-                        elog(ERROR, "pgaudit stack is not empty");
-                    }
-
-                    nextItem = nextItem->next;
-                }
-                while (nextItem != NULL);
-            }
+                elog(ERROR, "pgaudit stack is not empty");
 
             stackItem = stack_push();
-            stackItem->auditEvent.paramList = copyParamList(params);
+            stackItem->auditEvent.paramList = params;
         }
         else
             stackItem = stack_push();
@@ -1399,19 +1384,6 @@ pgaudit_ProcessUtility_hook(Node *parsetree,
             stackItem->auditEvent.commandTag == T_DoStmt &&
             !IsAbortedTransactionBlockState())
             log_audit_event(stackItem);
-
-        /*
-         * A close will free the open cursor which will also free the close
-         * audit entry. Immediately log the close and set stackItem to NULL so
-         * it won't be logged later.
-         */
-        if (stackItem->auditEvent.commandTag == T_ClosePortalStmt)
-        {
-            if (auditLogBitmap & LOG_MISC && !IsAbortedTransactionBlockState())
-                log_audit_event(stackItem);
-
-            stackItem = NULL;
-        }
     }
 
     /* Call the standard process utility chain. */
@@ -1844,7 +1816,7 @@ _PG_init(void)
     if (inited)
         return;
 
-    /* Must be loaded with shared_preload_libraries */
+    /* Must be loaded with shared_preload_libaries */
     if (!process_shared_preload_libraries_in_progress)
         ereport(ERROR, (errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
                 errmsg("pgaudit must be loaded via shared_preload_libraries")));
@@ -1873,7 +1845,7 @@ _PG_init(void)
 
         "Specifies that session logging should be enabled in the case where "
         "all relations in a statement are in pg_catalog.  Disabling this "
-        "setting will reduce noise in the log from tools like psql and PgAdmin "
+         "setting will reduce noise in the log from tools like psql and PgAdmin "
         "that query the catalog heavily.",
 
         NULL,
@@ -2000,11 +1972,7 @@ _PG_init(void)
     object_access_hook = pgaudit_object_access_hook;
 
     /* Log that the extension has completed initialization */
-#ifndef EXEC_BACKEND
     ereport(LOG, (errmsg("pgaudit extension initialized")));
-#else
-    ereport(DEBUG1, (errmsg("pgaudit extension initialized")));
-#endif /* EXEC_BACKEND */
 
     inited = true;
 }
