@@ -643,7 +643,7 @@ ALTER AGGREGATE public.sum_test(integer) RENAME TO sum_test2;
 
 --
 -- Test conversion
-CREATE CONVERSION public.conversion_test FOR 'latin1' TO 'utf8' FROM pg_catalog.iso8859_1_to_utf8;
+CREATE CONVERSION public.conversion_test FOR 'SQL_ASCII' TO 'MULE_INTERNAL' FROM pg_catalog.ascii_to_mic;
 ALTER CONVERSION public.conversion_test RENAME TO conversion_test2;
 
 --
@@ -666,24 +666,6 @@ CREATE SCHEMA foo2
 drop table public.t;
 drop role alice;
 
---
--- Test for non-empty stack error
-CREATE OR REPLACE FUNCTION get_test_id(_ret REFCURSOR) RETURNS REFCURSOR
-LANGUAGE plpgsql IMMUTABLE AS $$
-BEGIN
-    OPEN _ret FOR SELECT 200;
-    RETURN _ret;
-END $$;
-
-BEGIN;
-    SELECT get_test_id('_ret');
-    SELECT get_test_id('_ret2');
-    FETCH ALL FROM _ret;
-    FETCH ALL FROM _ret2;
-    CLOSE _ret;
-    CLOSE _ret2;
-END;
-
 --
 -- Test that frees a memory context earlier than expected
 SET pgaudit.log = 'ALL';
@@ -774,7 +756,10 @@ GRANT UPDATE
    TO auditor;
 
 INSERT INTO aaa VALUES (generate_series(1,100));
+
+SET pgaudit.log_parameter TO OFF;
 INSERT INTO bbb VALUES (1);
+SET pgaudit.log_parameter TO ON;
 
 DROP TABLE bbb;
 DROP TABLE aaa;
@@ -794,7 +779,6 @@ SET client_min_messages = 'warning';
 
 ALTER ROLE :current_user RESET pgaudit.log;
 ALTER ROLE :current_user RESET pgaudit.log_catalog;
-ALTER ROLE :current_user RESET pgaudit.log_client;
 ALTER ROLE :current_user RESET pgaudit.log_level;
 ALTER ROLE :current_user RESET pgaudit.log_parameter;
 ALTER ROLE :current_user RESET pgaudit.log_relation;
